==> jc-1.4.0.tar.gz: soot/jimple/internal/AbstractFloatBinopExpr.h <==
// public abstract class soot.jimple.internal.AbstractFloatBinopExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class b3123b7fa425fe58 soot_jimple_internal_AbstractFloatBinopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractBinopExpr

#include "soot/jimple/internal/AbstractBinopExpr.h"

#ifndef _JC_soot_jimple_internal_AbstractFloatBinopExpr_H_
#define _JC_soot_jimple_internal_AbstractFloatBinopExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Type$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_refs	_jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_nonrefs	_jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$refs	_jc_soot_jimple_internal_AbstractFloatBinopExpr$refs;
typedef struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$nonrefs	_jc_soot_jimple_internal_AbstractFloatBinopExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$object	_jc_soot_jimple_internal_AbstractFloatBinopExpr$object;

typedef const struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$vmethods	_jc_soot_jimple_internal_AbstractFloatBinopExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$vtable	_jc_soot_jimple_internal_AbstractFloatBinopExpr$vtable;
typedef const struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$vtype	_jc_soot_jimple_internal_AbstractFloatBinopExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_AbstractFloatBinopExpr$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$object *);

// Virtual methods
extern struct _jc_soot_Type$object *_jc_soot_jimple_internal_AbstractFloatBinopExpr$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_AbstractFloatBinopExpr$method_info$getType$847707b1f3b96fef;

// Virtual methods structure
struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$vmethods {
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$object *);
};

// Vtable
struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractFloatBinopExpr$vmethods	soot_jimple_internal_AbstractFloatBinopExpr;
};

// Vtype
struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_AbstractFloatBinopExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$refs {
    _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_refs	soot_jimple_internal_AbstractFloatBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractFloatBinopExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$object {
	_jc_soot_jimple_internal_AbstractFloatBinopExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_AbstractFloatBinopExpr$vtype	*vtype;
	_jc_soot_jimple_internal_AbstractFloatBinopExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_AbstractFloatBinopExpr$vtype _jc_soot_jimple_internal_AbstractFloatBinopExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_AbstractFloatBinopExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_AbstractFloatBinopExpr$class_object;

#endif	/* _JC_soot_jimple_internal_AbstractFloatBinopExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/AbstractFloatBinopExpr.h <==
// public abstract class soot.jimple.internal.AbstractFloatBinopExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class b3123b7fa425fe58 soot_jimple_internal_AbstractFloatBinopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractBinopExpr

#include "soot/jimple/internal/AbstractBinopExpr.h"

#ifndef _JC_soot_jimple_internal_AbstractFloatBinopExpr_H_
#define _JC_soot_jimple_internal_AbstractFloatBinopExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Type$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_refs	_jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_nonrefs	_jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$refs	_jc_soot_jimple_internal_AbstractFloatBinopExpr$refs;
typedef struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$nonrefs	_jc_soot_jimple_internal_AbstractFloatBinopExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$object	_jc_soot_jimple_internal_AbstractFloatBinopExpr$object;

typedef const struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$vmethods	_jc_soot_jimple_internal_AbstractFloatBinopExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$vtable	_jc_soot_jimple_internal_AbstractFloatBinopExpr$vtable;
typedef const struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$vtype	_jc_soot_jimple_internal_AbstractFloatBinopExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_AbstractFloatBinopExpr$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_Type$object *_jc_soot_jimple_internal_AbstractFloatBinopExpr$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_AbstractFloatBinopExpr$method_info$getType$847707b1f3b96fef;

// Virtual methods structure
struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$vmethods {
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractFloatBinopExpr$vmethods	soot_jimple_internal_AbstractFloatBinopExpr;
};

// Vtype
struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_AbstractFloatBinopExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$refs {
    _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_refs	soot_jimple_internal_AbstractFloatBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractFloatBinopExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_AbstractFloatBinopExpr$object {
	_jc_soot_jimple_internal_AbstractFloatBinopExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_AbstractFloatBinopExpr$vtype	*vtype;
	_jc_soot_jimple_internal_AbstractFloatBinopExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_AbstractFloatBinopExpr$vtype _jc_soot_jimple_internal_AbstractFloatBinopExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_AbstractFloatBinopExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_AbstractFloatBinopExpr$class_object;

#endif	/* _JC_soot_jimple_internal_AbstractFloatBinopExpr_H_ */
